import { Component, ElementRef, Input, OnChanges, OnInit, ViewChild, ViewEncapsulation } from '@angular/core';
import { DomSanitizer, SafeHtml } from '@angular/platform-browser';
@Component({
  selector: 'lib-highlightLib',
 templateUrl: './highlight-lib.component.html',

  styles: ['.mark {background-color: yellow}'],
  encapsulation : ViewEncapsulation.None

})
export class HighlightLibComponent implements OnInit , OnChanges {

  public replacedInputText: SafeHtml | undefined;

  @Input() public color: string = 'yellow' as string; // default yellow color
  @Input() public query: string = '' as string;

  // refrence of original content
  @ViewChild('inputs', { static: true }) public inputs: ElementRef | undefined;

  constructor(private sanitizer: DomSanitizer) {}

  public ngOnInit(): void {
    // gets text from original content
    this.replacedInputText = this.inputs?.nativeElement?.innerText;
  }

  /**
   * research on any changes in query/color
   */
  public ngOnChanges(): void {
    this.search();
  }

  public search(): void {
    // replacing the original content
    this.replacedInputText = this.sanitizer.bypassSecurityTrustHtml(
      this.inputs?.nativeElement?.innerText?.replace(
        new RegExp(this.query, 'g'),
        // Using Color Code
        `<span style="background-color:${this.color}">${this.query}</span>`
      )
    );
  }
}


